==> replicated-config-render-1.0.0.tgz: package/components/ConfigGroup.jsx <==
var _ = require('lodash');
var marked = require('marked');
var React = require('react');

var ConfigItem = require('./ConfigItem.jsx');
var ConfigGroupDescription = require('./ConfigGroupDescription.jsx');
var ConfigTestWidget = require('./ConfigTestWidget.jsx');

var ConfigGroup = React.createClass({
  getItem: function(itemName) {
    var item = null;
    _.some(this.props.allItems, function(otherItem) {
      if (otherItem.name === itemName) {
        item = otherItem;
        return true;
      } else {
        return _.some(otherItem.Items, function(otherChildItem) {
          if (otherChildItem.name === itemName) {
            item = otherChildItem;
            return true;
          }
          return false;
        });
      }
    });
    return item;
  },

  isItemVisible: function(item) {
    var checkWhen = function(item, value, ne) {
      if (ne) {
        return _.get(item, 'value', '').length > 0 ? item.value !== value : item.default !== value;
      } else {
        return _.get(item, 'value', '').length > 0 ? item.value === value : item.default === value;
      }
    };

    if (item.hidden) {
      return false;
    }

    if (_.get(item, 'when', '').length > 0) {
      var when = item.when.split('=', 2);
      if (when.length === 2) {
        var opNe = false,
          itemName = when[0],
          itemValue = when[1];
        if (itemName.substr(itemName.length - 1) === '!') {
          opNe = true;
          itemName = itemName.substr(0, itemName.length - 1);
        }
        var theItem = this.getItem(itemName);
        if (theItem !== null) {
          return checkWhen(theItem, itemValue, opNe);
        }
      }
    }

    return true;
  },

  isAtLeastOneItemVisible: function() {
    return _.some(this.props.group.items, function(item) {
      return this.isItemVisible(item);
    }.bind(this));
  },

  handleItemChange: function(itemName, value, data) {
    this.props.handleChange && this.props.handleChange(itemName, value, data);
  },

  render: function() {
    if (!this.isAtLeastOneItemVisible()) {
      return <span></span>;
    }

    var title = null;
    if (this.props.group.title) {
      title = (
        <div className="col-xs-12">
          <div className="page-header">
            <div className="spacer"></div>
            <h3 className="group-title">{this.props.group.title}</h3>
          </div>
        </div>
      );
    }

    var description = null;
    if (this.props.group.description) {
      description = (
        <ConfigGroupDescription text={this.props.group.description} />
      );
    }

    var items = _.map(this.props.group.items, function(item) {
      return (
        <ConfigItem
          key={item.name}
          item={item}
          allItems={this.props.allItems}
          visible={this.isItemVisible(item)}
          handleChange={this.handleItemChange} />
      );
    }.bind(this));

    var testWidget = null;
    if (_.get(this.props.group, 'test_proc.command', '').length > 0) {
      testWidget = (
        <div className="form-group col-xs-12">
          <ConfigTestWidget
            testProc={this.props.group.test_proc}
            allItems={this.props.allItems} />
        </div>
      );
    }

    return (
      <div className="config-group row clearfix">
        {title}
        {description}
        {items}
        {testWidget}
      </div>
    );
  }
});

module.exports = ConfigGroup;

==> replicated-config-render-1.0.1.tgz: package/components/ConfigGroup.jsx <==
var _ = require('lodash');
var marked = require('marked');
var React = require('react');

var ConfigItem = require('./ConfigItem.jsx');
var ConfigGroupDescription = require('./ConfigGroupDescription.jsx');
var ConfigTestWidget = require('./ConfigTestWidget.jsx');

var ConfigGroup = React.createClass({
  getItem: function(itemName) {
    var item = null;
    _.some(this.props.allItems, function(otherItem) {
      if (otherItem.name === itemName) {
        item = otherItem;
        return true;
      } else {
        return _.some(otherItem.items, function(otherChildItem) {
          if (otherChildItem.name === itemName) {
            item = otherChildItem;
            return true;
          }
          return false;
        });
      }
    });
    return item;
  },

  isItemVisible: function(item) {
    var checkWhen = function(item, value, ne) {
      if (ne) {
        return _.get(item, 'value', '').length > 0 ? item.value !== value : item.default !== value;
      } else {
        return _.get(item, 'value', '').length > 0 ? item.value === value : item.default === value;
      }
    };

    if (item.hidden) {
      return false;
    }

    if (_.get(item, 'when', '').length > 0) {
      var when = item.when.split('=', 2);
      if (when.length === 2) {
        var opNe = false,
          itemName = when[0],
          itemValue = when[1];
        if (itemName.substr(itemName.length - 1) === '!') {
          opNe = true;
          itemName = itemName.substr(0, itemName.length - 1);
        }
        var theItem = this.getItem(itemName);
        if (theItem !== null) {
          return checkWhen(theItem, itemValue, opNe);
        }
      }
    }

    return true;
  },

  isAtLeastOneItemVisible: function() {
    return _.some(this.props.group.items, function(item) {
      return this.isItemVisible(item);
    }.bind(this));
  },

  handleItemChange: function(itemName, value, data) {
    this.props.handleChange && this.props.handleChange(itemName, value, data);
  },

  render: function() {
    if (!this.isAtLeastOneItemVisible()) {
      return <span></span>;
    }

    var title = null;
    if (this.props.group.title) {
      title = (
        <div className="col-xs-12">
          <div className="page-header">
            <div className="spacer"></div>
            <h3 className="group-title">{this.props.group.title}</h3>
          </div>
        </div>
      );
    }

    var description = null;
    if (this.props.group.description) {
      description = (
        <ConfigGroupDescription text={this.props.group.description} />
      );
    }

    var items = _.map(this.props.group.items, function(item) {
      return (
        <ConfigItem
          key={item.name}
          item={item}
          allItems={this.props.allItems}
          visible={this.isItemVisible(item)}
          handleChange={this.handleItemChange} />
      );
    }.bind(this));

    var testWidget = null;
    if (_.get(this.props.group, 'test_proc.command', '').length > 0) {
      testWidget = (
        <div className="form-group col-xs-12">
          <ConfigTestWidget
            testProc={this.props.group.test_proc}
            allItems={this.props.allItems} />
        </div>
      );
    }

    return (
      <div className="config-group row clearfix">
        {title}
        {description}
        {items}
        {testWidget}
      </div>
    );
  }
});

module.exports = ConfigGroup;
